@@ -9,7 +9,9 @@ Networks, using `scikit-learn`_.
 import pandas as pd
 import numpy as np
 from scipy import stats
-from grenadine.Inference.inference import rank_GRN
+import matplotlib.pyplot as plt
+import networkx as nx
+from grenadine.Inference.inference import rank_GRN,clean_nan_inf_scores
 from sklearn.decomposition import PCA
 from sklearn.metrics import roc_curve
 from sklearn.metrics import roc_auc_score
@@ -347,7 +349,7 @@ def KneeLocator(fpr, tpr):
     i = np.argmin(distances)
     return i
 
-def get_y_targets(scores, gold_std_grn, n_links=100000):
+def get_y_targets(gold_std_grn, scores=None, ranks=None, n_links=100000):
     """
     Get ground truth and predictor's estimation of a GRN, in a format ready to
     be used in sklearn.metrics functions.
@@ -358,6 +360,10 @@ def get_y_targets(scores, gold_std_grn, n_links=100000):
             The value at row i and column j represents the score assigned by a
             score_predictor to the regulatory relationship between target gene i
             and transcription factor j.
+        ranks (pandas.DataFrame): ranking matrix. A ranking matrix contains a
+            row for each possible regulatory link, it also contains 4 columns,
+            namely the rank, the score, the transcription factor id, and the
+            target gene id.
         gold_std_grn (pandas.DataFrame): reference GRN used as a gold standard,
             where rows are links with index of the type <TF symbol>_<TG symbol>,
             and columns are respectively 'TF':TF symbol, 'TG':TG symbol, and
@@ -403,7 +409,7 @@ def get_y_targets(scores, gold_std_grn, n_links=100000):
         gene1_gene3  gene1  gene3             0
         gene3_gene2  gene3  gene2             1
         gene3_gene1  gene3  gene1             0
-        >>> y_true, y_pred, y_pred_binary = get_y_targets(scores, grn, n_links=3)
+        >>> y_true, y_pred, y_pred_binary = get_y_targets(scores=scores, grn, n_links=3)
         >>> y_true
         gene1_gene3    0
         gene1_gene2    1
@@ -418,18 +424,14 @@ def get_y_targets(scores, gold_std_grn, n_links=100000):
         gene3_gene2    1
 
     """
-
-    # replacing NaN scores with minimum score -1
-    nan_scores = np.isnan(scores)
-    min_score =  scores[np.logical_not(nan_scores)].min().min()
-    scores[nan_scores] = min_score-1
-    # replacing infinite scores with maximum score + 1
-    finite_scores = np.isfinite(scores)
-    max_score =  scores[finite_scores].max().max()
-    scores[np.logical_not(finite_scores)] = max_score+1
-
-    ranks = rank_GRN(coexpression_scores_matrix=scores)
-
+    if scores is None and ranks is None:
+        return None
+    if scores is not None and ranks is None:
+        scores = clean_nan_inf_scores(scores)
+        ranks = rank_GRN(coexpression_scores_matrix=scores,take_abs_score=False)
+    if(len(ranks.shape)==1):
+        ranks = pd.DataFrame(ranks,columns=["rank"])# the best method is ranked 1
+        ranks["score"] = ranks["rank"].max() - ranks["rank"]
     ranks_top = ranks.iloc[:n_links,:] # taking only n_links best links
     mutual_edges = set(ranks_top.index).intersection(set(gold_std_grn.index)) # taking links that are both in ranks_top and in the golden standard
     if not len(mutual_edges):
@@ -512,7 +514,9 @@ def evaluate_result(scores, gold_std_grn, n_links=100000):
 
     """
 
-    y_true, y_pred, y_pred_binary = get_y_targets(scores, gold_std_grn, n_links)
+    y_true, y_pred, y_pred_binary = get_y_targets(gold_std_grn,
+                                                  scores=scores,
+                                                  n_links=n_links)
     if y_true is None:
         metrics_dict = {"AUROC": 0,
                         "AUPR": 0,
